==> shared-0.11.10.jar: project.clj <==
(defproject offcourse/shared "0.11.10"
  :description     "This is an echo lambda function. It's mainly used for debugging purposes."
  :url             "http://example.com/FIXME"
  :license         {:name "Eclipse Public License"
                    :url "http://www.eclipse.org/legal/epl-v10.html"}
  :plugins         [[lein-cljsbuild "1.1.7"]]
  :dependencies    [[org.clojure/clojure         "1.9.0-alpha17"]
                    [funcool/cuerdas             "2.0.3"]
                    [com.rpl/specter             "1.0.3"]
                    [org.clojure/core.async      "0.3.443"]
                    [offcourse/specs             "0.1.1"]
                    [org.clojure/clojurescript   "1.9.854"]]
  :repositories [["snapshots" {:url "https://clojars.org/repo"
                               :username :env/CLOJARS_USER
                               :password :env/CLOJARS_PASS}]
                  ["releases" {:url "https://clojars.org/repo"
                              :sign-releases false
                              :username :env/CLOJARS_USER
                              :password :env/CLOJARS_PASS}]]
  :profiles {:dev {:dependencies [[com.cemerick/piggieback "0.2.2"]
                                  [org.clojure/tools.nrepl "0.2.10"]]
                   :repl-options {:nrepl-middleware [cemerick.piggieback/wrap-cljs-repl]}}}
  :deploy-repositories [["clojars" {:url "https://clojars.org/repo"
                                    :username :env/CLOJARS_USER
                                    :password :env/CLOJARS_PASS
                                    :sign-releases false}]]
  :aliases {"bump" ["change" "version" "leiningen.release/bump-version"]}
  :release-tasks [["change" "version" "leiningen.release/bump-version" "release"]
                  ["deploy" "clojars"]]
  :cljsbuild       {:builds [{:id "prod"
                              :source-paths ["src"]
                              :compiler {:target :nodejs
                                         :optimizations :simple
                                         :pretty-print true
                                         :parallel-build true}}]})

==> shared-0.11.20.jar: project.clj <==
(defproject offcourse/shared "0.11.20"
  :description     "This is an echo lambda function. It's mainly used for debugging purposes."
  :url             "http://example.com/FIXME"
  :license         {:name "Eclipse Public License"
                    :url "http://www.eclipse.org/legal/epl-v10.html"}
  :plugins         [[lein-cljsbuild "1.1.7"]
                    [lein-pprint "1.1.2"]]
  :dependencies    [[org.clojure/clojure         "1.9.0-alpha17"]
                    [funcool/cuerdas             "2.0.3"]
                    [com.rpl/specter             "1.0.3"]
                    [org.clojure/core.async      "0.3.443"]
                    [offcourse/specs             "0.1.15"]
                    [org.clojure/clojurescript   "1.9.854"]]
  :repositories [["snapshots" {:url "https://clojars.org/repo"
                               :username :env/CLOJARS_USER
                               :password :env/CLOJARS_PASS}]
                  ["releases" {:url "https://clojars.org/repo"
                              :sign-releases false
                              :username :env/CLOJARS_USER
                              :password :env/CLOJARS_PASS}]]
  :profiles {:dev {:dependencies [[com.cemerick/piggieback "0.2.2"]
                                  [org.clojure/tools.nrepl "0.2.10"]]
                   :repl-options {:nrepl-middleware [cemerick.piggieback/wrap-cljs-repl]}}}
  :deploy-repositories [["clojars" {:url "https://clojars.org/repo"
                                    :username :env/CLOJARS_USER
                                    :password :env/CLOJARS_PASS
                                    :sign-releases false}]]
  :aliases {"bump" ["change" "version" "leiningen.release/bump-version"]}
  :release-tasks [["change" "version" "leiningen.release/bump-version" "release"]
                  ["deploy" "clojars"]]
  :cljsbuild       {:builds [{:id "prod"
                              :source-paths ["src"]
                              :compiler {:target :nodejs
                                         :optimizations :simple
                                         :pretty-print true
                                         :parallel-build true}}]})
